//---------------------------------------------------------------------------
#include <vcl.h>
#pragma hdrstop

#include "cipherfrm.h"
#include <swmgr.h>
#include <swconfig.h>

using namespace std;
using namespace sword;

//---------------------------------------------------------------------------
#pragma package(smart_init)
#pragma resource "*.dfm"
TCipherForm *CipherForm;
//---------------------------------------------------------------------------
__fastcall TCipherForm::TCipherForm(TComponent* Owner)
	: TForm(Owner)
{
}
//---------------------------------------------------------------------------
void __fastcall TCipherForm::Button2Click(TObject *Sender)
{
	SectionMap::iterator section;
	ConfigEntMap::iterator entry;
	SWBuf tmpBuf;
	
	section = config->Sections.find(modName);
	if (section != config->Sections.end()) {
		entry = section->second.find("CipherKey");
		if (entry != section->second.end()) {
			entry->second = CipherForm->cipherEdit->Text.c_str();
			config->Save();
			SWMgr *mgr = new SWMgr();
			SWModule *mod = mgr->Modules[modName];
			mod->setKey("Ipet 2:12");
			tmpBuf = mod->StripText();
			mod->setKey("gen 1:10");
			tmpBuf += "\r\n\r\n";
			tmpBuf += mod->StripText();
			Memo1->Text = tmpBuf.c_str();
			delete mgr;
		}
	}
}
//---------------------------------------------------------------------------

void __fastcall TCipherForm::FormShow(TObject *Sender)
{
	SWBuf tmpCaption;
	tmpCaption = "Cipher Key: [";
	tmpCaption += modName;
	tmpCaption += "]";
	Caption = tmpCaption.c_str();
}
//---------------------------------------------------------------------------


void __fastcall TCipherForm::FormClose(TObject *Sender,
      TCloseAction &Action)
{
	Memo1->Text = "";	
}
//---------------------------------------------------------------------------

